@@ -36,10 +36,11 @@ disclaimer = '''
     '''
 
 output_about = '''
-    mutation wave plot - select one or multiple files to plot mutation wave (mutation number vs cells number)
-    fitness wave plot - select one or multiple files to plot fitness wave (not active for analytical model)
+    single mutation wave plot - select one or multiple files to plot mutation wave (mutation number vs cells number)
     population growth plot - select multiple files to plot how population grow between generations
-    combined mutation wave plot - select two or more files to combine mutation wave plots on one plot (able for normal and analytical wave plot)
+    multiple mutation wave plot - select two or more files to combine mutation wave plots on one plot (able for normal and analytical wave plot)
+    evolution dynamics - comparision of analytical and normal model data - select whole population for both versions (generations should be corresponding).
+        plot will contain three mutation waves in 1/4, 2/4, 3/4 of generation size, population groth and mutation changes throught evolution
 '''
 
 class mainFormat(qtWidget.QWidget):
@@ -56,6 +57,7 @@ class mainFormat(qtWidget.QWidget):
         self._th_cp = Process()
         self._th_mw = Process()
         self._th_fw = Process()
+        self._th_ed = Process()
         self.createMainView()
         self._monitor = True
         self.th_monitor = Thread(target=self.monitor, args=(self.q, self.status))
@@ -79,6 +81,7 @@ class mainFormat(qtWidget.QWidget):
                 if data[0] == '0':
                     status.setText("ID: " + data[1] + ", generation: " + data[2])
                 elif data[0] == 'exit':
+                    status.setText("stopped: " + data[1])
                     for i in self.s_ID:
                         if i == data[1]:
                             idx = self.s_ID.index(i)
@@ -110,6 +113,11 @@ class mainFormat(qtWidget.QWidget):
                 if not self._th_cp.is_alive():                   
                     self.status.setText("combined plot done")
                     # self._th_fw = None
+            if self._th_ed.is_alive():
+                self._th_ed.join(1)   
+                if not self._th_ed.is_alive():                 
+                    self.status.setText("evolution dynamics done")
+                    # self._th_mw = None
     
     def update(self):
         i = self.tabs.indexOf(self._tabUI)
@@ -184,6 +192,33 @@ class mainFormat(qtWidget.QWidget):
             self.status.setText("combined mutation wave plot ongoing")
         else:
             self.showDialog("Wrong file/files extension. Use only one kind at time", "Alert")
+            
+    def evolutionDynamics(self):
+        if self._th_ed.is_alive():
+            self.showDialog("plottin already running", 'Info')
+            return
+        self.showDialog("First select ANALYTICAL .npz files (whole population)\n Second select NORMAL .npz files (whole population)", "INFO")
+        fname_an = qtWidget.QFileDialog.getOpenFileNames(None, 'Select Analytical Files', "Z://","Data File (*.npz)")[0] 
+        if len(fname_an) == 0:
+            self.showDialog("No analytical file selected", "Alert")
+            return
+        if not all(map(lambda x: 'analytical' in x, fname_an)):
+            self.showDialog("Select only analytical files", "Alert")
+            return
+        fname_norm = qtWidget.QFileDialog.getOpenFileNames(None, 'Select Normal Files', "Z://","Data File (*.npz)")[0] 
+        if len(fname_norm) == 0:
+            self.showDialog("No normal file selected", "Alert")
+            return
+        if not all(map(lambda x: 'normal' in x, fname_norm)):
+            self.showDialog("Select only normal files", "Alert")
+            return
+        if all(map(lambda x: x.endswith('.npz'), fname_an)) and all(map(lambda x: x.endswith('.npz'), fname_norm)):
+            self._th_ed = (Process(target=externalPlots.evolutionDynamics, args=(fname_an, fname_norm)))
+            # externalPlots.evolutionDynamics(fname_an, fname_norm)
+            self._th_ed.start()
+            self.status.setText("evolution dynamics plot ")
+        else:
+            self.showDialog("Wrong file/files extension.", "Alert")
     
     def createMainView(self):
         layout = qtWidget.QGridLayout()
@@ -231,7 +266,7 @@ class mainFormat(qtWidget.QWidget):
         layout = qtWidget.QGridLayout()
 
         self._NONE = qtWidget.QRadioButton("Checked: Normal simulation")       
-        self._analytical = qtWidget.QRadioButton("Checked: Analytical model (omit VAF)")               
+        self._analytical = qtWidget.QRadioButton("Checked: Analytical model")               
         self._NONE.click()
         
         self._file_name = qtWidget.QLineEdit()
@@ -341,13 +376,16 @@ class mainFormat(qtWidget.QWidget):
         dfp.to_csv(filepath)  
     
     def loadParams(self):
-        fname = qtWidget.QFileDialog.getOpenFileName(self, 'Open file', "Z://","CSV files (*.csv)")        
+        fname = qtWidget.QFileDialog.getOpenFileName(self, 'Open file', "Z://","CSV files (*.csv)") 
+        if fname[0] == '':
+            self.showDialog("No file selected!", "Alert")
+            return
         df = pd.read_csv(fname[0])
         df = df.to_numpy()        
     
-        self._population.setText(str(df[0,1]))
-        self._capacity.setText(str(df[1,1]))
-        self._steps.setText(str(df[2,1]))
+        self._population.setText(str(int(df[0,1])))
+        self._capacity.setText(str(int(df[1,1])))
+        self._steps.setText(str(int(df[2,1])))
         self._tau.setText(str(df[3,1]))
         self._skip.setText(str(df[4,1]))
         self._mut_prob.setText(str(df[5,1]))
@@ -363,7 +401,7 @@ class mainFormat(qtWidget.QWidget):
         layout.addWidget(self._sx, row, 0)
 
         _mut_wave = qtWidget.QPushButton(self)
-        _mut_wave.setText('Mutation wave plot')
+        _mut_wave.setText('Mutation wave plot - single mutation wave on figure')
         _mut_wave.clicked.connect(self.mutWaveAction)
         row = row + 1
         layout.addWidget(_mut_wave, row, 0)
@@ -381,11 +419,17 @@ class mainFormat(qtWidget.QWidget):
         layout.addWidget(_pop_growth, row, 0)
         
         _combined = qtWidget.QPushButton(self)
-        _combined.setText('Combined mutation wave plot')
+        _combined.setText('Mutation wave plot - multiple mutation waves on figure')
         _combined.clicked.connect(self.combinedMutWave)
         row = row + 1
         layout.addWidget(_combined, row, 0)
         
+        _dyn = qtWidget.QPushButton(self)
+        _dyn.setText('Evolution dynamics')
+        _dyn.clicked.connect(self.evolutionDynamics)
+        row = row + 1
+        layout.addWidget(_dyn, row, 0)
+        
         _about = qtWidget.QPushButton(self)
         _about.setText('Short instruction')
         _about.clicked.connect(self.showAboutOutput)
@@ -422,6 +466,8 @@ class mainFormat(qtWidget.QWidget):
             layout.addRow(qtWidget.QLabel("mutation wave"), qtWidget.QLabel())
         if self._th_fw.is_alive():
             layout.addRow(qtWidget.QLabel("fitness wave"), qtWidget.QLabel())
+        if self._th_ed.is_alive():
+            layout.addRow(qtWidget.QLabel("evolution dynamics"), qtWidget.QLabel())
         
         threadTabUI.setLayout(layout)
         return threadTabUI
@@ -442,14 +488,14 @@ class mainFormat(qtWidget.QWidget):
         
         iPop = []
         if self._analytical.isChecked():
-            iPop = np.array([0,params[0]])
-            iPop = sc.sparse.csr_matrix(iPop)
+            iPop = np.array([[0],[float(params[0])]])
             select = 1
             name = 'analytical'
         else:
             iPop = np.ones(params[0])
             iMuts = np.zeros(params[0])
             iPop = sc.sparse.csr_matrix(np.array([iPop, iMuts]).T)
+            # iPop = np.array([iPop, iMuts]).T
             select = 0
             name = 'normal'
           
